Pyrone_tr = {
'AJAX_REQUEST_ERROR': 'Ошибка выполнения AJAX-запроса',
'ARTICLE_SAVED': 'Статья сохранена.',
'BACKUP_RESTORE_COMPLETE': 'Бэкап успешно восстановлен',
'COMMENT_BODY_IS_REQUIRED': 'Текст комментария обязателен',
'COMMENT_DISPLAY_NAME_IS_REQUIRED': 'Имя автора комментария обязательно к заполнению',
'COMMENT_IS_WAITING_FOR_APPROVAL': 'Комментарий ожидает одобрения администратора сайта',
'FIELD_IS_REQUIRED': 'Поле обязательно для заполнения',
'FIELD_MUST_BE_ALPHA_NUM': 'Поле должно содержать только буквенно-цифровые символы',
'FILE_NAME_ALREADY_EXISTS_IN_THE_STORAGE': 'Файл с таким именем уже есть в хранилище',
'PASSWORDS_DONT_MATCH': 'Пароли не совпадают',
'POSTING_COMMENT': 'Отправка комментария…',
'SELECT_FILE_TO_UPLOAD': 'Выберите файл для загрузки',
'SELECT_ITEMS_FIRST': 'Сначала выберите элементы',
'SETTINGS_SAVED': 'Настройки успешно сохранены',
'TWITTER_AUTH_IS_NOT_WORKING': 'Аутентификация через Twitter не работает',
'YOUR_PROFILE_HAS_BEEN_UPDATED': 'Ваш профиль успешно обновлён'
};
